% Dynamical System of the Khan, King and Wolman (2000) 'Optimal Monetary Policy' 
% Program to implement numerical linearisation of the system of equations for 
% the King and Watson solution program KW98REV_1
%
% Aubhik 04.06.00, changed for system0 on 14.11.2000.
%
% related programs: 
%
% DynamicList	produces ylist, xlist
% SYSTEM0		contains first order conditions
% DynamicDRV	defines Q, RHO and G for stochastic processess

load nowfile
cd Calibrations
eval ( ['load ', filename ])
cd ..

% set numerical difference term
tolerance = 1e-9;

% define steady state terms
nvars = length(Xsol);
% J = (nvars - 12)/5;
nshocks = length(shock);
zerovec = zeros(1,nvars);
Y = Xsol;
X = Xsol;

F = system0CE(X,Y,shock,paramCE);

Amat = zeros(nvars,nvars);
Cmat = zeros(nvars,nshocks);
A = Amat;
B = Amat;
CF = Cmat;

% numerical linearisation of the current endogenous variables
for i = 1:1:nvars
   dev = zerovec;
   h = tolerance;
   dev(i) = h;
   
   Xdev = Xsol + dev;   
   Fdev = system0CE(Xdev,Y,shock, paramCE);
   DF = Fdev - F;
   DF = DF./h;
   
   if (i~= 2*J) 				% current nominal rate
      if ( i ~= 5+3*J)		% lagged nominal rate
         if (Xsol(i) ~= 0)
            DF = DF.*Xsol(i);
         end
     end
   end
   
   B(:,i) = DF';
   
end

% numerical linearisation of the future endogenous variables
for i = 1:1:nvars
   dev = zerovec;
   h = tolerance;
   dev(i) = h;
   
   Ydev = Y + dev;   
   Fdev = system0CE(X,Ydev,shock, paramCE);
   DF = Fdev - F;
   DF = DF./h;
   
   if (i~= 2*J) 		% current nominal rate
      if ( i ~= 5+3*J)	% lagged nominal rate
         if (Xsol(i) ~= 0)
            DF = DF.*Xsol(i);
         end
      end
   end
   
   A(:,i) = DF';
   
end

A = -1.*A;	% system of equation is written to equal 0.

% numerical linearisation of teh exogenous variables.
zerovec = zeros(1,nshocks);

for i = 1:1:nshocks
   dev = zerovec;
   h = tolerance;
   dev(i) = h;
   
   shockdev = shock + dev;   
   Fdev = system0CE(X,Y,shockdev, paramCE);
   DF = Fdev - F;
   DF = DF./h;
   
   if (shock(i) ~= 0)
      DF = DF.*shock(i);
   end

   CF(:,i) = DF';
   
end

ny = length(X);
lpd = [6+2*J:1:5+3*J];					% from steadydriverCE's declaration of variables
nx = 3;									% this implies nlead = 1 (no leads) 
[ylist, xlist] = DynamicListCE(J);      % see DynamicList for details


  
   
   
   
   
   
   

