% recover steady state variables from solution vector generated using steadydriver
%
% Aubhik, 14.11.2000.

% housekeeping
clear
clc

% obtain name of steady state file to recover variable names
filename = input( ' enter name of datafile containing steady state: ','s');

eval ([ ' load Calibrations\', filename ] )


% static multipliers at time t
mdelta = Xsol(1);
mxi = Xsol(2);
momega = Xsol(3);
mrho = Xsol(4);
mlambda = Xsol(5);

for i = 1:1:J-1
   eval ([ ' mq', num2str(i),' = Xsol(6 + i - 1); ' ] );
end

% Xsol(6:4+J) = [mq1 mq2 mq3 mq4 mq5 mq6 mq7 mq8];

% choices at time t
mphi = Xsol(5+J);
mpsi = Xsol(5+2*J);					
s = Xsol(6+2*J:5+3*J); 
R = Xsol(6+3*J);						% nominal rate of interest between this period and the neXsolt
c = Xsol(7+3*J);						% consumption
xi = Xsol(8+3*J);						% fraction of goods bought using credit
lambda = Xsol(9+3*J);                   % relative price of output for household
l = Xsol(10+3*J);						% leisure
n = Xsol(11+3*J);						% hours worked
iinfl = Xsol(12+3*J);                   % inflation

% state variables at the beginning of period t
slag = Xsol(13+3*J: 11+4*J);
mphilag = Xsol(12+4*J:10+5*J);
Rlag = Xsol(11+5*J);					
mpsilag = Xsol(12+5*J);			

Abar = shock(1);                        % multiplicative productivity 
xbar = shock(2);                        % additive productivity
zbar = shock(3);                        % money demand disturbance

epsilon = param(1);                     % elasticity of substitution across consumption goods
theta = param(2);                       % preference weight on leisure
eta = param(3);                         % elasticity of labour supply
betas = param(4);                       % subjective discount factor
bplanner = param(5);
p0cc = param(6);                        % cost of credit fraction of goods without credit cost parameter
p1cc = param(7);
alphacc = param(8);                     % cost of credit beta distribution parameter
betacc = param(9);                      % cost of credit beta distrbution parameter	
kcc = param(10);                        % cost of credit scale parameter
J = param(11);                          % nominal price setting horizon
omega = param(12: 11 + J);              % adjustment probabilities for price-setting			

% computer utility terms
etaterm = 1 - eta;
U    = log(c) + theta*(l^(1-eta))/(1-eta);
D1U  = 1/c;													
D2U  = theta*(l^-eta);						
D11U = -1*D1U*D1U;										
D22U = -eta*theta*(l^-(1+eta));	
D12U = 0;							

% the argument for the beta inverse cost distribution function. Note the adjustment by kcc
xadj = R*c*lambda/(D2U*kcc);

B1 = beta(alphacc, betacc);
B2 = beta(alphacc + 1, betacc);

if (xadj < 1)
   if (xadj > 0)
      B3 = betainc(xadj, alphacc, betacc);
      B4 = betainc(xadj, alphacc + 1, betacc);
   else
      B3 = 0;
      B4 = 0;
   end
else
   B3 = 1;
   B4 = 1;
end

F = p0cc + p1cc*B3;
IntF = kcc*p1cc*(B2/B1)*B4;
DF = p1cc*(1/kcc)*(xadj^(alphacc - 1))*( (1 - xadj)^(betacc-1))/B1;

