% Khan, King and Wolman (2000) COMPETITIVE EQUILIBRIUM Steady State solution driver program 
%
% Aubhik Khan 04.09.2001

% COMPETITIVE EQUILIBRIUM PROGRAMS INVOLVE SETTING THE INFLATION RATE.

clear
clc

homotopy = 'y';                     % record the solution Xsol to use as an initial condition
solve = 'y';						% resolve the steady state?

% Declare variable locations and X and param within a mat-file

inputfile = input( ' parameter filename: ','s');

cd Calibrations
eval (inputfile);
cd ..

% If a previous solution saved Xsol in a file named guess.m, and if 
% the current inputfile loads this initial condition, then it will be 
% used instead of direct term by term entry in the calibration file.   

if (exist('Xsol') ~= 1)
    
   disp ( ' using directly entered initial conditions ' )
   X = zeros(1,5+3*J);
    
    s = svec;
    slag = svec(1:J-1);
    Rlag = R;
    
    % choices at time t		
    X(J:2*J-1) = s; 
    X(2*J) = R;                         % nominal rate of interest between this period and the next
    X(1+2*J) = c;						% consumption
    X(2+2*J) = xi;                      % fraction of goods bought using credit
    X(3+2*J) = lambda;                  % relative price of output for household
    X(4+2*J) = l;						% leisure
    X(5+2*J) = n;						% hours worked
    %X(6+2*J) = iinfl;                  % inflation
    paramCE = [param iinfl -999 0 0 0];
    
    % state variables at the beginning of period t
    X(6+2*J: 4+3*J) = slag;
    X(5+3*J) = Rlag;					
    
    %%%%%%%%%%%%%%%%%%%%%%%%%
    %						%
    %	Computation of V(j)	%
    %						%
    %%%%%%%%%%%%%%%%%%%%%%%%%
    
    epsilonterm = (epsilon - 1)/epsilon;
    zp = 1;
    D2U = theta*(l^-eta);
    V = zeros(1,J);
    
    for i = J-1:-1:1
        share = s(zp + i);
        Xv = share^epsilonterm;
        Xv = (1-epsilon)*Xv + epsilon*share*(D2U/(lambda*Abar));
        Xv = lambda*Xv*c;
        V(i) = omega(zp+i)*Xv + beta*V(i+1);
    end
    
    V = V(1:J-1);
    
    X(1:J-1) = V;	
    
else
    
   disp ( ' using Xsol vector from a file named guess ' )
    
    X = Xsol;
    s = X(J:2*J - 1);
    l = X(4+2*J);	
    lambda = X(3+2*J);
    c = X(1+2*J);
    epsilonterm = (epsilon - 1)/epsilon;
    zp = 1;
    D2U = theta*(l^-eta);
    V = zeros(1,J);
    
    for i = J-1:-1:1
        share = s(zp + i);
        Xv = share^epsilonterm;
        Xv = (1-epsilon)*Xv + epsilon*share*(D2U/(lambda*Abar));
        Xv = lambda*Xv*c;
        V(i) = omega(zp+i)*Xv + beta*V(i+1);
    end
    
end

% consistency check for recursive first-order form
share = s(zp);
Xv = share^epsilonterm;
Xv = (1-epsilon)*Xv + epsilon*share*(D2U/(lambda*Abar));
Xv = lambda*Xv*c;
error = omega(zp)*Xv + beta*V(1);

disp ([ ' the recursive first order form implies an error of ', num2str(error) ] )

disp ( ' evaluation of the initial condition ' )
SteadyStateCE(X, shock, paramCE)

if (solve == 'y')
tolerance = 1e-8;

[Xsol, Fsol, refined] = SteadyNEQ('SteadyStateCE', X, shock, paramCE, 1, tolerance, 1);

disp ( ' change in the endogenous variables ' )
disp([X - Xsol])

Xsol = [Xsol iinfl];
paramCE = [param iinfl 0 0 Xsol(1+2*J) Xsol(2*J)];

else
   
   Xsol = [Xsol iinfl];
   paramCE = [param iinfl 0 0 Xsol(1+2*J) Xsol(2*J)];

end
daytime = datestr(now);

% save results in a mat file that does not overwrite existing files and 
eval ( [ ' cd Calibrations ';]);
filecount = 0;
filexist = exist([savedata '.mat']);
filenameappend = savedata;

while (filexist ~= 0)
   filecount = filecount + 1;
   filenameappend = [savedata '_' num2str(filecount) ];
   filexist = exist([filenameappend '.mat']);
end


eval ( [ ' save ',filenameappend, ' Xsol paramCE shock J daytime' ] );

if (homotopy == 'y')
    disp ( ' saving solution Xsol in file named guess ' )
    save guessCE Xsol
end

cd ..

disp ( [ ' Parameterisation and Steady State Solution saved as ', filenameappend,'.mat ' ] )

